pub struct Extract<T: FromInput>(/* private fields */);Expand description
Generic extractor wrapper — delegates to T::from_input.
Use this in element parameters to extract any FromInput type
without giving it a more specific semantic role like Attr or Fields.
Implementations