Variants

Struct Variants 

pub struct Variants(/* private fields */);
Element extractor that pulls enum variants from the input.

Errors at compile time if the input is not an enum. Access the inner Punctuated<syn::Variant, syn::token::Comma> via Deref or the inner() method.

#[zyn::element]
fn my_element(#[zyn(input)] variants: zyn::Variants) -> proc_macro2::TokenStream {
    // variants.iter() — accessed via Deref to Punctuated<syn::Variant, syn::token::Comma>
}

Implementations

Source

impl Variants

pub fn inner(self) -> Punctuated<Variant, Comma>

Consumes the wrapper and returns the inner Punctuated<syn::Variant, syn::token::Comma>.

Methods from Deref<Target = Punctuated<Variant, Comma>>

pub fn is_empty(&self) -> bool

Determines whether this punctuated sequence is empty, meaning it contains no syntax tree nodes or punctuation.

pub fn len(&self) -> usize

Returns the number of syntax tree nodes in this punctuated sequence.

This is the number of nodes of type T, not counting the punctuation of type P.

pub fn first(&self) -> Option<&T>

Borrows the first element in this sequence.

pub fn first_mut(&mut self) -> Option<&mut T>

Mutably borrows the first element in this sequence.

pub fn last(&self) -> Option<&T>

Borrows the last element in this sequence.

pub fn last_mut(&mut self) -> Option<&mut T>

Mutably borrows the last element in this sequence.

pub fn get(&self, index: usize) -> Option<&T>

Borrows the element at the given index.

pub fn get_mut(&mut self, index: usize) -> Option<&mut T>

Mutably borrows the element at the given index.

pub fn iter(&self) -> Iter<'_, T>

Returns an iterator over borrowed syntax tree nodes of type &T.

pub fn iter_mut(&mut self) -> IterMut<'_, T>

Returns an iterator over mutably borrowed syntax tree nodes of type &mut T.

pub fn pairs(&self) -> Pairs<'_, T, P>

Returns an iterator over the contents of this sequence as borrowed punctuated pairs.

pub fn pairs_mut(&mut self) -> PairsMut<'_, T, P>

Returns an iterator over the contents of this sequence as mutably borrowed punctuated pairs.

pub fn push_value(&mut self, value: T)

Appends a syntax tree node onto the end of this punctuated sequence. The sequence must already have a trailing punctuation, or be empty.

Use push instead if the punctuated sequence may or may not already have trailing punctuation.

Panics

Panics if the sequence is nonempty and does not already have a trailing punctuation.

pub fn push_punct(&mut self, punctuation: P)

Appends a trailing punctuation onto the end of this punctuated sequence. The sequence must be non-empty and must not already have trailing punctuation.

Panics

Panics if the sequence is empty or already has a trailing punctuation.

pub fn pop(&mut self) -> Option<Pair<T, P>>

Removes the last punctuated pair from this sequence, or None if the sequence is empty.

pub fn pop_punct(&mut self) -> Option<P>

Removes the trailing punctuation from this punctuated sequence, or None if there isn’t any.

pub fn trailing_punct(&self) -> bool

Determines whether this punctuated sequence ends with a trailing punctuation.

pub fn empty_or_trailing(&self) -> bool

Returns true if either this Punctuated is empty, or it has a trailing punctuation.

Equivalent to punctuated.is_empty() || punctuated.trailing_punct().

pub fn push(&mut self, value: T)
where P: Default,

Appends a syntax tree node onto the end of this punctuated sequence.

If there is not a trailing punctuation in this sequence when this method is called, the default value of punctuation type P is inserted before the given value of type T.

pub fn insert(&mut self, index: usize, value: T)
where P: Default,

Inserts an element at position index.

Panics

Panics if index is greater than the number of elements previously in this punctuated sequence.

pub fn clear(&mut self)

Clears the sequence of all values and punctuation, making it empty.