pub fn note(message: impl Into<String>) -> DiagnosticBuilderExpand description
Creates a note diagnostic builder with the given message.
pub fn note(message: impl Into<String>) -> DiagnosticBuilderCreates a note diagnostic builder with the given message.