pub struct Fmt(pub &'static str);Expand description
Formats the input using a pattern string, producing a string literal.
The {} placeholder in the pattern is replaced with the input value.
Template usage: {{ name | fmt:"hello {}" }}
Tuple Fields
0: &'static strTrait Implementations