pub struct Ident(pub &'static str);Expand description
Formats the input using a pattern string, producing an Ident.
The {} placeholder in the pattern is replaced with the input value.
Template usage: {{ name | ident:"get_{}" }}
Tuple Fields
0: &'static strTrait Implementations