pub struct Template {
pub nodes: Vec<Node>,
}Expand description
A parsed template AST. Created by parsing template syntax via syn::parse2::<Template>(tokens).
Fields
nodes: Vec<Node>Implementations
Sourceimpl Template
impl Template
Sourcepub fn span(&self) -> Span
pub fn span(&self) -> Span
Returns the source span of the first node, or Span::call_site() if empty.
Sourcepub fn to_token_stream(&self) -> TokenStream
pub fn to_token_stream(&self) -> TokenStream
Expands the template into a TokenStream without an Input binding.
Sourcepub fn render(&self, input: &Input) -> TokenStream
pub fn render(&self, input: &Input) -> TokenStream
Expands the template with the given Input bound as input in the generated code.